@@ -2,8 +2,8 @@
 #  File:           CARDTargetFeatureProvider.py
 #  Date:           12-Jun-2021 jdw
 #
-#  Updated:
-#
+#  Updates:
+#   14-Mar-2023 dwp  CARD feature data will stop being used temporarily (in favor of CARD annotations)
 ##
 """
 Accessors and generators for CARD target feature data.
@@ -99,7 +99,7 @@ class CARDTargetFeatureProvider(StashableBase):
         for queryId, matchDL in mD.items():
             qCmtD = self.__decodeComment(queryId)
             modelId = qCmtD["modelId"]
-            if not cardP.hasFeature(modelId):
+            if not cardP.hasModel(modelId):
                 logger.info("Skipping CARD model %r", modelId)
                 continue
 
@@ -113,9 +113,9 @@ class CARDTargetFeatureProvider(StashableBase):
                 tCmtD = self.__decodeComment(matchD["target"])
                 entryId = tCmtD["entityId"].split("_")[0]
                 entityId = tCmtD["entityId"].split("_")[1]
-                nm = cardP.getFeature(modelId, "modelName")
-                descr = cardP.getFeature(modelId, "descr")
-                featureId = cardP.getFeature(modelId, "id")
+                nm = cardP.getModelValue(modelId, "modelName")
+                descr = cardP.getModelValue(modelId, "descr")
+                featureId = cardP.getModelValue(modelId, "cvTermId")
                 rD = {
                     "entry_id": entryId,
                     "entity_id": entityId,
